=======
History
=======

0.1.0 (2020-03-02)
------------------

* First release on PyPI.

1.2.0 (2020-06-10)
------------------

* Added support for referencing task using started by value

1.2.3 (2020-09-09)
------------------

* Make task parameter optional for service based deploys

2.0.0 (2020-10-22)
------------------

* Add support for selecting aws profile

2.0.1 (2021-10-28)
------------------

* Add support for specifying ssh user and path of the ssh key in bastion node

3.0.0 (2022-06-29)
------------------

* Add support for ecs exec command
